Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(288)

Unified Diff: chrome/browser/chromeos/login/ownership_service.h

Issue 6821075: Chrome-side lockbox bindings (Closed) Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: CL RC1. Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/ownership_service.h
diff --git a/chrome/browser/chromeos/login/ownership_service.h b/chrome/browser/chromeos/login/ownership_service.h
index 194ab18a33500fd1862bf58eb8ff72852bc30b0c..d7cb7854b81ba6f0b81702a3ea0f0ede472e1001 100644
--- a/chrome/browser/chromeos/login/ownership_service.h
+++ b/chrome/browser/chromeos/login/ownership_service.h
@@ -29,7 +29,8 @@ class OwnershipService : public NotificationObserver {
// Listed in upgrade order.
OWNERSHIP_UNKNOWN = 0,
OWNERSHIP_NONE,
- OWNERSHIP_TAKEN
+ OWNERSHIP_USER,
+ OWNERSHIP_ENTERPRISE
};
// Returns the singleton instance of the OwnershipService.
@@ -71,8 +72,8 @@ class OwnershipService : public NotificationObserver {
// This method can be run either on FILE or UI threads. If |blocking| flag
// is specified then it is guaranteed to return either OWNERSHIP_NONE or
// OWNERSHIP_TAKEN (and not OWNERSHIP_UNKNOWN), however in this case it may
// occasionally block doing i/o.
virtual Status GetStatus(bool blocking);
protected:
@@ -104,6 +105,7 @@ class OwnershipService : public NotificationObserver {
const std::vector<uint8>& signature,
OwnerManager::Delegate* d);
static void FailAttempt(OwnerManager::Delegate* d);
+ static Status DetermineOwnerType();
OwnerManager* manager() { return manager_.get(); }

Powered by Google App Engine
@@ -71,8 +72,8 @@ class OwnershipService : public NotificationObserver {
// This method can be run either on FILE or UI threads. If |blocking| flag
// is specified then it is guaranteed to return either OWNERSHIP_NONE or
- // OWNERSHIP_TAKEN (and not OWNERSHIP_UNKNOWN), however in this case it may
- // occasionally block doing i/o.
+ // OWNERSHIP_USER or OWNERSHIP_ENTERPRISE (and not OWNERSHIP_UNKNOWN), however
+ // in this case it may occasionally block doing i/o.
virtual Status GetStatus(bool blocking);
protected:
This is Rietveld 408576698